==> haskell-monadprompt-1.0.0.5-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monadprompt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 MonadPrompt
version:              1.0.0.5
visibility:           public
id:                   MonadPrompt-1.0.0.5-8YK89c9akLh3vOIQNoeMCz
key:                  MonadPrompt-1.0.0.5-8YK89c9akLh3vOIQNoeMCz
license:              BSD-3-Clause
copyright:            (c) 2008 Ryan Ingram & Bertram Felgenhauer & Cale Gibbard
maintainer:           ryani.spam@gmail.com
author:               Ryan Ingram
stability:            experimental
synopsis:             MonadPrompt, implementation & examples
description:
    \"Prompting\" monad that allows splitting the description
    of a computation from the implementation of the effects
    used in that computation.
    <http://www.haskell.org/pipermail/haskell-cafe/2008-January/038301.html>

category:             Control
abi:                  aa613c6807ea20fdb527ff9f8cc6b4d4
exposed:              True
exposed-modules:      Control.Monad.Prompt
import-dirs:          /usr/lib/ghc-9.0.2/site-local/MonadPrompt-1.0.0.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/MonadPrompt-1.0.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/MonadPrompt-1.0.0.5
hs-libraries:         HSMonadPrompt-1.0.0.5-8YK89c9akLh3vOIQNoeMCz
depends:              base-4.15.1.0 mtl-2.2.2
haddock-interfaces:   /usr/share/doc/haskell-monadprompt/html/MonadPrompt.haddock
haddock-html:         /usr/share/doc/haskell-monadprompt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monadprompt-1.0.0.5-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monadprompt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 MonadPrompt
version:              1.0.0.5
visibility:           public
id:                   MonadPrompt-1.0.0.5-2LatcwGGS2Q5uLEuFYBrfY
key:                  MonadPrompt-1.0.0.5-2LatcwGGS2Q5uLEuFYBrfY
license:              BSD-3-Clause
copyright:            (c) 2008 Ryan Ingram & Bertram Felgenhauer & Cale Gibbard
maintainer:           ryani.spam@gmail.com
author:               Ryan Ingram
stability:            experimental
synopsis:             MonadPrompt, implementation & examples
description:
    \"Prompting\" monad that allows splitting the description
    of a computation from the implementation of the effects
    used in that computation.
    <http://www.haskell.org/pipermail/haskell-cafe/2008-January/038301.html>

category:             Control
abi:                  209211abdf4271107108abb2d640382f
exposed:              True
exposed-modules:      Control.Monad.Prompt
import-dirs:          /usr/lib/ghc-9.2.8/site-local/MonadPrompt-1.0.0.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/MonadPrompt-1.0.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monadprompt
hs-libraries:         HSMonadPrompt-1.0.0.5-2LatcwGGS2Q5uLEuFYBrfY
depends:              base-4.16.4.0 mtl-2.2.2
haddock-interfaces:   /usr/share/doc/haskell-monadprompt/html/MonadPrompt.haddock
haddock-html:         /usr/share/doc/haskell-monadprompt/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
